

// Display the results as a string of black text on a white background.
global.displayStr = "Running test...\n";

draw_set_font(LogFont);
draw_set_colour(c_black);

function DoDraw()
{
	draw_text(30, 30, global.displayStr);
}

// Called to run the benchmark
function Test()
{
	// Run a short warmup to ensure CPU caches/JIT is working at peak performance
	var count = CountPrimesInRange(0, 10000);
	global.displayStr += "Warmup: found " + string(count) + " primes\n";
	
	// Run real benchmark, timing how long it takes to count all primes between
	// 1 million and 2 million
	var startTime = current_time;
	
	count = CountPrimesInRange(1000000, 2000000);
	
	// Update text with timing result
	global.displayStr += "Benchmark: found " + string(count) + " primes in " + string(round(current_time - startTime)) + "ms\n";
}

// Return the number of primes found in a number range.
function CountPrimesInRange(startNum, endNum)
{
	var primeCount = 0;
	for (var i = startNum; i < endNum; ++i)
	{
		if (IsPrime(i))
			primeCount++;
	}
	return primeCount;
}

// Determine if a given number is prime.
function IsPrime(n)
{
	if (n == 1)
		return true;
	if (n % 2 == 0)
		return false;
	
	var limit = floor(sqrt(n));
	for (var f = 3; f <= limit; f += 2)
	{
		if (n % f == 0)
			return false;
	}
	
	return true;
}

// Run the benchmark.
Test();